@@ -15,7 +15,7 @@ use HTML::TokeParser::Simple;
 use B::Deparse;
 
 use vars qw( $VERSION @EXPORT %munge_map );
-$VERSION = '0.46';
+$VERSION = '0.48';
 @EXPORT = qw( &shell );
 
 =head1 NAME
@@ -108,7 +108,8 @@ sub init {
 		verbose => 0,
   };
   # Install the request dumper :
-  $self->{request_wrapper} = wrap *LWP::UserAgent::request,
+  $self->{request_wrapper} = wrap 'LWP::UserAgent::request',
+      #pre => sub { printf STDERR "Dumping? %s\n",$self->option("dumprequests"); $self->request_dumper($_[1]) if $self->option("dumprequests"); },
       pre => sub { $self->request_dumper($_[1]) if $self->option("dumprequests"); },
       post => sub {
                     $self->response_dumper($_[-1]) if $self->option("dumpresponses");
@@ -163,7 +164,10 @@ circular reference. This method does this.
 
 sub release_agent {
   my ($self) = @_;
+  use Data::Dumper;
+  warn Dumper $self;
   undef $self->{request_wrapper};
+  undef $self->{redirect_ok_wrapper};
   $self->{agent} = undef;
 };
 
@@ -1322,23 +1326,12 @@ Set basic authentication credentials.
 
 Syntax:
 
-  auth [authority realm] user password
-
-If you get back a 401, you can simply supply the matching
-user and password, as the authority and realm are already
-known :
-
-	>get http://www.example.com
-	Retrieving http://www.example.com(401)
-	http://www.example.com>auth corion secret
-	http://www.example.com>get http://www.example.com
-	Retrieving http://www.example.com(200)
-	http://www.example.com>
+  auth user password
 
 If you know the authority and the realm in advance, you can
 presupply the credentials, for example at the start of the script :
 
-	>auth www.example.com:80 secure_realm corion secret
+	>auth corion secret
 	>get http://www.example.com
 	Retrieving http://www.example.com(200)
 	http://www.example.com>
@@ -1347,36 +1340,23 @@ presupply the credentials, for example at the start of the script :
 
 sub run_auth {
     my ($self) = shift;
-    my ($authority, $realm, $user, $password);
+    my ($user, $password);
     if (scalar @_ == 2) {
-      unless ($self->agent->res) {
-        print "Can't guess authentification elements without a request.";
-        print "Use the four parameter version instead.";
-        return;
-      };
-
       ($user,$password) = @_;
+      $password = "" if not defined $password;
+
       my $code = sub {
-          if ($self->agent->res->www_authenticate =~ /\brealm=(['"]?)(.*)\1/) {
-            $realm = $2
-          } else {
-            #$self->warn_user();
-            $realm = "";
-          };
-          $authority = $self->agent->{req}->uri->authority();
-          $self->agent->credentials($authority,$realm,$user => $password);
+          $self->agent->credentials($user => $password);
       };
       $code->();
       my $body = $self->munge_code($code);
 
       $self->add_history(
-          sprintf( q{my ($user,$password) = ('%s','%s')}, $user, $password),
+          sprintf( q{my ($user,$password) = ('%s','%s');}, $user, $password),
           $body,
       );
     } else {
-      ($authority, $realm, $user, $password) = @_;
-      $self->add_history( sprintf q{$agent->credentials('%s','%s','%s','%s');}, $authority,$realm,$user,$password);
-      $self->agent->credentials($authority,$realm,$user => $password);
+        $self->display_user_warning("Authentication only supports the two-argument form");
     };
 };
 
@@ -2054,7 +2034,7 @@ invocation of the shell like with CPAN :
 
 This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
-Copyright (C) 2002,2003 Max Maischein
+Copyright (C) 2002,2008 Max Maischein
 
 =head1 AUTHOR
 
